@@ -9,8 +9,6 @@
 
 """Extension initialization tests."""
 
-from __future__ import absolute_import, print_function
-
 from flask import Flask
 
 from invenio_records_rest import InvenioRecordsREST
@@ -20,14 +18,15 @@ from invenio_records_rest.utils import PIDConverter
 def test_version():
     """Test version import."""
     from invenio_records_rest import __version__
+
     assert __version__
 
 
 def test_init():
     """Test extension initialization."""
-    app = Flask('testapp')
-    app.url_map.converters['pid'] = PIDConverter
+    app = Flask("testapp")
+    app.url_map.converters["pid"] = PIDConverter
     ext = InvenioRecordsREST()
-    assert 'invenio-records-rest' not in app.extensions
+    assert "invenio-records-rest" not in app.extensions
     ext.init_app(app)
-    assert 'invenio-records-rest' in app.extensions
+    assert "invenio-records-rest" in app.extensions
